==> AffyTiling_1.4.0.zip: AffyTiling/doc/AffyTiling.R <==
###################################################
### chunk number 1: 
###################################################
library(AffyTiling)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap")


###################################################
### chunk number 3:  eval=FALSE
###################################################
## colnames(EXP)
## EXP[1:10,1:5]


###################################################
### chunk number 4:  eval=FALSE
###################################################
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", makeUniqueID=FALSE, readProbeSeq=TRUE)


###################################################
### chunk number 5:  eval=FALSE
###################################################
## iID <- c(1:3)
## iCHR <- c("chr1", "chr2", "chr3")
## iSTART <- rep(1, 3)
## iEND <- iSTART+1000000
## Einter <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", iID= iID, iCHR= iCHR, iSTART= iSTART, iEND= iEND)


###################################################
### chunk number 6: 
###################################################
data(KnownGenes)
colnames(KG)


###################################################
### chunk number 7: 
###################################################
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13))
head(NearestGenes)


###################################################
### chunk number 8: 
###################################################
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13), D=1000)


###################################################
### chunk number 9: 
###################################################
GeneOfInterest <- NearestGenes[which(NearestGenes[,2] == "AY358517"),]


###################################################
### chunk number 10: 
###################################################
lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),] })[1:10]


###################################################
### chunk number 11: 
###################################################
ExpSample1 <- as.real( lapply( GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),4] } ) )
GenomicPos <- as.integer(lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),2] }))
plot(GenomicPos, ExpSample1)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## CpG <-read.table("CpG-Table.tsv", header=TRUE, sep="\t")

==> AffyTiling_1.8.0.zip: AffyTiling/doc/AffyTiling.R <==
###################################################
### chunk number 1: 
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
library(AffyTiling)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 48 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap")


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
## colnames(EXP)
## EXP[1:10,1:5]


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 61 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
## EXP <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", makeUniqueID=FALSE, readProbeSeq=TRUE)


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 68 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
## iID <- c(1:3)
## iCHR <- c("chr1", "chr2", "chr3")
## iSTART <- rep(1, 3)
## iEND <- iSTART+1000000
## Einter <- AnalyzeTilingCelFiles(dir(pattern=".cel|.CEL"), "Hs_PromPR_v02-3_NCBIv34.bpmap", iID= iID, iCHR= iCHR, iSTART= iSTART, iEND= iEND)


###################################################
### chunk number 6: 
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
data(KnownGenes)
colnames(KG)


###################################################
### chunk number 7: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13))
head(NearestGenes)


###################################################
### chunk number 8: 
###################################################
#line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
NearestGenes <- AssociateWithGenes(KG[ , 1], KG[ , 2], KG[ , 3], KG[ , 4], KG[ , 5], Einter[ , 1], Einter[ , 3], (as.integer(Einter[ , 2])+13), D=1000)


###################################################
### chunk number 9: 
###################################################
#line 108 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
GeneOfInterest <- NearestGenes[which(NearestGenes[,2] == "AY358517"),]


###################################################
### chunk number 10: 
###################################################
#line 114 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),] })[1:10]


###################################################
### chunk number 11: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
ExpSample1 <- as.real( lapply( GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),4] } ) )
GenomicPos <- as.integer(lapply(GeneOfInterest[,1], function(x) { Einter[which(Einter[,1] == x),2] }))
plot(GenomicPos, ExpSample1)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 151 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6mSNOr/R.INSTALL6f431e98/AffyTiling/inst/doc/AffyTiling.Rnw"
## CpG <-read.table("CpG-Table.tsv", header=TRUE, sep="\t")
